Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2011)

Unified Diff: Source/modules/screen_orientation/ScreenOrientationController.h

Issue 1026253002: Rename FrameDestructionObserver to LocalFrameLifecycleObserver. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: rebased Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/modules/screen_orientation/ScreenOrientationController.h
diff --git a/Source/modules/screen_orientation/ScreenOrientationController.h b/Source/modules/screen_orientation/ScreenOrientationController.h
index 414c6842127d17640b82d4c2c6bcc0967680ce76..584dbb24172ed0f8e825bf530b35cc3f96329226 100644
--- a/Source/modules/screen_orientation/ScreenOrientationController.h
+++ b/Source/modules/screen_orientation/ScreenOrientationController.h
@@ -5,7 +5,7 @@
#ifndef ScreenOrientationController_h
#define ScreenOrientationController_h
-#include "core/frame/FrameDestructionObserver.h"
+#include "core/frame/LocalFrameLifecycleObserver.h"
#include "core/frame/PlatformEventController.h"
#include "platform/Supplementable.h"
#include "platform/Timer.h"
@@ -22,7 +22,7 @@ class WebScreenOrientationClient;
class ScreenOrientationController final
: public NoBaseWillBeGarbageCollectedFinalized<ScreenOrientationController>
, public WillBeHeapSupplement<LocalFrame>
- , public FrameDestructionObserver
+ , public LocalFrameLifecycleObserver
, public PlatformEventController {
WILL_BE_USING_GARBAGE_COLLECTED_MIXIN(ScreenOrientationController);
WTF_MAKE_NONCOPYABLE(ScreenOrientationController);
@@ -53,7 +53,7 @@ private:
virtual bool hasLastData() override;
virtual void pageVisibilityChanged() override;
// Inherited from FrameDestructionObserver.
virtual void willDetachFrameHost() override;
void notifyDispatcher();
@@ -53,7 +53,7 @@ private:
virtual bool hasLastData() override;
virtual void pageVisibilityChanged() override;
- // Inherited from FrameDestructionObserver.
+ // Inherited from LocalFrameLifecycleObserver.
virtual void willDetachFrameHost() override;
void notifyDispatcher();

Powered by Google App Engine
This is Rietveld 408576698